==> huaweicloudsdkgsl-3.1.113-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/network_switch_policy_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NetworkSwitchPolicyReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'network_switch_policy_id': 'int'
    }

    attribute_map = {
        'network_switch_policy_id': 'network_switch_policy_id'
    }

    def __init__(self, network_switch_policy_id=None):
        """NetworkSwitchPolicyReq

        The model defined in huaweicloud sdk

        :param network_switch_policy_id: 网络切换策略标识
        :type network_switch_policy_id: int
        """
        
        

        self._network_switch_policy_id = None
        self.discriminator = None

        self.network_switch_policy_id = network_switch_policy_id

    @property
    def network_switch_policy_id(self):
        """Gets the network_switch_policy_id of this NetworkSwitchPolicyReq.

        网络切换策略标识

        :return: The network_switch_policy_id of this NetworkSwitchPolicyReq.
        :rtype: int
        """
        return self._network_switch_policy_id

    @network_switch_policy_id.setter
    def network_switch_policy_id(self, network_switch_policy_id):
        """Sets the network_switch_policy_id of this NetworkSwitchPolicyReq.

        网络切换策略标识

        :param network_switch_policy_id: The network_switch_policy_id of this NetworkSwitchPolicyReq.
        :type network_switch_policy_id: int
        """
        self._network_switch_policy_id = network_switch_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkSwitchPolicyReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkgsl-3.1.137-py2.py3-none-any.whl: huaweicloudsdkgsl/v3/model/network_switch_policy_req.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class NetworkSwitchPolicyReq:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'cid': 'str',
        'network_switch_policy_id': 'int'
    }

    attribute_map = {
        'cid': 'cid',
        'network_switch_policy_id': 'network_switch_policy_id'
    }

    def __init__(self, cid=None, network_switch_policy_id=None):
        """NetworkSwitchPolicyReq

        The model defined in huaweicloud sdk

        :param cid: 容器ID
        :type cid: str
        :param network_switch_policy_id: 网络切换策略标识
        :type network_switch_policy_id: int
        """
        
        

        self._cid = None
        self._network_switch_policy_id = None
        self.discriminator = None

        if cid is not None:
            self.cid = cid
        self.network_switch_policy_id = network_switch_policy_id

    @property
    def cid(self):
        """Gets the cid of this NetworkSwitchPolicyReq.

        容器ID

        :return: The cid of this NetworkSwitchPolicyReq.
        :rtype: str
        """
        return self._cid

    @cid.setter
    def cid(self, cid):
        """Sets the cid of this NetworkSwitchPolicyReq.

        容器ID

        :param cid: The cid of this NetworkSwitchPolicyReq.
        :type cid: str
        """
        self._cid = cid

    @property
    def network_switch_policy_id(self):
        """Gets the network_switch_policy_id of this NetworkSwitchPolicyReq.

        网络切换策略标识

        :return: The network_switch_policy_id of this NetworkSwitchPolicyReq.
        :rtype: int
        """
        return self._network_switch_policy_id

    @network_switch_policy_id.setter
    def network_switch_policy_id(self, network_switch_policy_id):
        """Sets the network_switch_policy_id of this NetworkSwitchPolicyReq.

        网络切换策略标识

        :param network_switch_policy_id: The network_switch_policy_id of this NetworkSwitchPolicyReq.
        :type network_switch_policy_id: int
        """
        self._network_switch_policy_id = network_switch_policy_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NetworkSwitchPolicyReq):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
